@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -
-from flask_sqlalchemy import SQLAlchemy
 from .gt_flask import GtFlask
 from .constant import VERSION
 import logging.config
@@ -22,9 +21,11 @@ def create_app(config):
     app.init_app()
     app.config.from_object(config)
 
-    app.logger.info('初始化数据库...')
-    db = SQLAlchemy(app)
-    app.db = db
+    if app.config['SQLALCHEMY_DATABASE_URI']:
+        init_sqlalchemy(app)
+
+    if app.config['MONGO_URI']:
+        init_mongodb(app)
 
     from .processor import Processor
     app.logger.info('初始化任务处理器...')
@@ -75,3 +76,18 @@ def unload_modules():
             uninit_app(app)
         except:
             app.logger.warning('Unload Module [{}] Error.'.format(module.__name__))
+
+def init_sqlalchemy(app):
+    from flask_sqlalchemy import SQLAlchemy
+    app.logger.info('初始化数据库...')
+    db = SQLAlchemy(app)
+    app.db = db
+
+def init_mongodb(app):
+    from flask_pymongo import PyMongo
+    from webcore.mongo_encoder import MongoEncoder
+    app.logger.info('初始化MongoDB...')
+    mongo_db = PyMongo(app)
+    app.mongo_db = mongo_db
+    app.register_encoder(MongoEncoder())
+
