@@ -18,3 +18,9 @@ class GtFlask(Flask):
         self.json_encoder = ApiEncoder
         init_error_handler(self)
         init_interceptor(self)
+        
+    def register_encoder(self, encoder):
+        self.json_encoder.add_encoder(encoder)
+
+    def unregister_encoder(self, encoder):
+        self.json_encoder.remove_encoder(encoder)
\ No newline at end of file
